pub struct IndexedNumbers { /* private fields */ }Expand description
As is, only guarantees to allow up to u32 inputs, as it uses u64 as the index internally!
Implementations
Sourceimpl IndexedNumbers
impl IndexedNumbers
pub fn virtual_len(&self) -> u64
pub fn first(&self) -> Option<&u64>
pub fn last(&self) -> Option<&u64>
Sourcepub fn from_unsorted_weighted_value_vec(
weighted_values: &mut Vec<WeightedValue>,
) -> Result<Self, TooMuchIndexedNumbersWeightError>
pub fn from_unsorted_weighted_value_vec( weighted_values: &mut Vec<WeightedValue>, ) -> Result<Self, TooMuchIndexedNumbersWeightError>
As is, only allows up to u32 inputs for sure, as it uses u64 as the index internally, and the weights are u32, too; returns an error otherwise. Sorts the vec!